Token class

Token

Constructors

Token({required String id, required String status, String? authenticationId, AuthenticatedToken? authentication, required String maskedCardNumber, required bool should3ds, required CardInfo cardInfo})
Token.from(Map json)
Convert Map to Token
Token.fromAuthenticatedToken(AuthenticatedToken authentication, {ThreeDSRecommendation? tds})
Convert AuthenticatedToken to Token
Token.fromAuthentication(Authentication authentication, {String? tokenId})
Convert Authentication to Token

Properties

authentication AuthenticatedToken?
Authenticated Token
final
authenticationId String?
Authentication ID
final
cardInfo CardInfo
Card Info
final
hashCode int
The hash code for this object.
no setterinherited
id String
Token ID
final
maskedCardNumber String
Masked Card Number
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
should3ds bool
Should 3DS
final
status String
Status
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited